@@ -36,7 +36,7 @@ class Output(Plugin):
 
 class Trigger(Plugin):
     def __init__(self, pipeline: str, prid: Optional[int] = None):
-        super().__init__(pipeline, None)
+        super().__init__(pipeline, 0)
     
     def run(self):
         raise NotImplementedError
@@ -49,4 +49,7 @@ class PluginLoggerAdapter(logging.LoggerAdapter):
         self.prid = prid
 
     def process(self, msg, kwargs):
-        return f'[{self.pipeline}:{self.prid}] {msg}', kwargs
+        pipeline_str = self.pipeline
+        if self.prid != 0:
+            pipeline_str += f':{self.prid}'
+        return f'[{pipeline_str}] {msg}', kwargs
